# RxInfer Client

A Python client for interacting with RxInferServer.

## Features

- Simple and intuitive API
- Type hints for better IDE support
- Comprehensive documentation
- Built on top of OpenAPI specification

## Documentation

- [Installation](installation.md) - How to install the client

## API Reference

::: rxinferclient.wrapper.client
